( function () {
	/**
	 * Supported highlight colors.
	 * Warning: These are also hardcoded in "styles/mw.rcfilters.variables.less"
	 *
	 * @member mw.rcfilters
	 * @property {string[]}
	 */
	mw.rcfilters.HighlightColors = [ 'c1', 'c2', 'c3', 'c4', 'c5' ];
}() );
